@@ -1,7 +1,8 @@
-import sys
-from io import StringIO
+import shutil
+import time
 from pathlib import Path
 
+
 __author__ = "Duc Tin"
 
 
@@ -11,10 +12,7 @@ log = Path.cwd() / 'logs/log.txt'
 def remove_log():
     log_folder = log.parent
     if log_folder.exists():
-        for file in log_folder.iterdir():
-            file.unlink()
-        # else:
-        #     log_folder.unlink()
+        shutil.rmtree(log_folder)
 
 
 def pytest_runtest_setup(item):
@@ -46,7 +44,6 @@ def pytest_sessionstart(session):
     pass
 
 
-
 def pytest_sessionfinish(session, exitstatus):
     """
     Called after whole test run finished, right before
